@@ -106,26 +106,25 @@ class ConfigView(object):
         """Iterate over the keys of a dictionary view or the *subviews*
         of a list view.
         """
-        # Try getting the keys, if this is a dictionary view.
+        # Try iterating over the keys, if this is a dictionary view.
         try:
-            keys = self.keys()
-            for key in keys:
+            for key in self.keys():
                 yield key
 
         except ConfigTypeError:
-            # Otherwise, try iterating over a list.
-            collection = self.get()
-            if not isinstance(collection, (list, tuple)):
+            # Otherwise, try iterating over a list view.
+            try:
+                for subview in self.sequence():
+                    yield subview
+
+            except ConfigTypeError:
+                item, _ = self.first()
                 raise ConfigTypeError(
                     u'{0} must be a dictionary or a list, not {1}'.format(
-                        self.name, type(collection).__name__
+                        self.name, type(item).__name__
                     )
                 )
 
-            # Yield all the indices in the list.
-            for index in range(len(collection)):
-                yield self[index]
-
     def __getitem__(self, key):
         """Get a subview of this view."""
         return Subview(self, key)
@@ -295,6 +294,26 @@ class ConfigView(object):
 
     # List/sequence emulation.
 
+    def sequence(self):
+        """Iterates over the subviews contained in lists from the *first*
+        source at this view. If the object for this view in the first source
+        is not a list or tuple, then a `ConfigTypeError` is raised.
+        """
+        try:
+            collection, _ = self.first()
+        except NotFoundError:
+            return
+        if not isinstance(collection, (list, tuple)):
+            raise ConfigTypeError(
+                u'{0} must be a list, not {1}'.format(
+                    self.name, type(collection).__name__
+                )
+            )
+
+        # Yield all the indices in the sequence.
+        for index in range(len(collection)):
+            yield self[index]
+
     def all_contents(self):
         """Iterates over all subviews from collections at this view from
         *all* sources. If the object for this view in any source is not
@@ -630,11 +649,18 @@ class Configuration(RootView):
             os.makedirs(appdir)
         return appdir
 
-    def set_file(self, filename):
+    def set_file(self, filename, base_for_paths=False):
         """Parses the file as YAML and inserts it into the configuration
         sources with highest priority.
+
+        :param filename: Filename of the YAML file to load.
+        :param base_for_paths: Indicates whether the directory containing the
+            YAML file will be used as the base directory for resolving relative
+            path values stored in the YAML file. Otherwise, by default, the
+            directory returned by `config_dir()` will be used as the base.
         """
-        self.set(YamlSource(filename, loader=self.loader))
+        self.set(YamlSource(filename, base_for_paths=base_for_paths,
+                            loader=self.loader))
 
     def dump(self, full=True, redact=False):
         """Dump the Configuration object to a YAML file.
